#
# Configuration file for using the Bonobo library in GNOME applications
#
BONOBOX_LIBDIR="-L/usr/X11R6/lib"
BONOBOX_LIBS="-lbonobo -L/usr/X11R6/lib -L/usr/local/lib -lXpm -lgnomeui -lart_lgpl -lgdk_imlib -lungif -lSM -lICE -lgnome -lgnomesupport -lesd -laudiofile -lgdk_pixbuf -ltiff -ljpeg -lpng -lz -lgtk12 -lgdk12 -lgmodule12 -ldl -lxpg4 -lXext -lX11 -loaf -lORBitCosNaming -lORBit -lIIOP -lORBitutil -lglib12 -lintl -lwrap -lbonobox -L/usr/local/lib -lxml -lz"
BONOBOX_INCLUDEDIR="-I/usr/X11R6/include -I/usr/X11R6/include -DNEED_GNOMESUPPORT_H -I/usr/X11R6/include/gtk12 -I/usr/local/include/glib12 -I/usr/local/include -I/usr/local/include/gnome-xml -I/usr/local/include/orbit-1.0"
MODULE_VERSION="bonobo-1.0.7"
